@@ -1,5 +1,6 @@
 from datetime import datetime, timedelta
 from collections import Hashable
+import time
 import threading
 
 from .cross import imap, xrange
@@ -70,7 +71,7 @@ except ImportError:
 
 
 @decorator
-def retry(call, tries, errors=Exception):
+def retry(call, tries, errors=Exception, timeout=0):
     for attempt in xrange(tries):
         try:
             return call()
@@ -78,6 +79,10 @@ def retry(call, tries, errors=Exception):
             # Reraise error on last attempt
             if attempt + 1 == tries:
                 raise
+            else:
+                timeout_value = timeout(attempt) if callable(timeout) else timeout
+                if timeout_value > 0:
+                    time.sleep(timeout_value)
 
 
 def fallback(*approaches):
